/*
 * Project name:
     Virtual COM Port Demo
 * Description
     Example showing usage USB CDC device that functions as a generic virtual
     COM port withou driver installation by user. The example echoes data sent 
     via USART terminal.
 * Test configuration:
     MCU:             P32MX534F064H
     dev.board:       PIC32MX Clicker
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
     Notes:           Turn on USB VBUS switch.
                      The Code uses the USB Device Library from Libstock:
                      http://www.libstock.com/projects/view/568/usb-device-library
 */

#include <stdint.h>

// Buffer of 64 bytes
char buffer[64];

void USB1Interrupt() iv IVT_USB_1 ilevel 7 ics ICS_SRS{
  // Call library interrupt handler routine
  USBDev_IntHandler();
}

void USBDev_CDCParamsChanged(){

}

extern const uint8_t _USB_CDC_BULK_EP_IN;   // Data interface IN endpoint
extern const uint8_t _USB_CDC_BULK_EP_OUT;  // Data interface OUT endpoint

void USBDev_CDCDataReceived(uint16_t size){
  // Prepare receive buffer
  USBDev_CDCSetReceiveBuffer(buffer);
  // Send back received packet
  USBDev_CDCSendData(buffer, size);
}

void main() {
  AD1PCFG = 0xFFFF;                        // Configure AN pins as digital I/O

  // Initialize CDC Class
  USBDev_CDCInit();

  // Initialize USB device module
  USBDev_Init();

  // Enable USB device interrupt
  USBIE_bit = 1;
  IPC11bits.USBIP = 7;
  EnableInterrupts();

  // Wait until device is configured (enumeration is successfully finished)
  while(USBDev_GetDeviceState() != _USB_DEV_STATE_CONFIGURED)
    ;

  // Set receive buffer where received data is stored
  USBDev_CDCSetReceiveBuffer(buffer);

  // Infinite loop
  while(1){

  }

}